from __future__ import annotations

import typing

if typing.TYPE_CHECKING:
    StrOrBool: typing.TypeAlias = "str | bool"
